@@ -184,7 +184,7 @@ QString LinkedInAPI::search_person(QString search, QString start, QString count)
   */
 QString LinkedInAPI::search_company(QString search,QString start, QString count){
 	search = QUrl::toPercentEncoding(search);
-	return api_request("http://api.linkedin.com/v1/company-search:(companies:(id,name,universal-name,website-url,logo-url,type),num-results)?start="+start+"&count="+count+"&keywords=" + search);
+	return api_request("http://api.linkedin.com/v1/company-search:(companies:(id,name,universal-name,website-url,logo-url,square-logo-url,type),num-results)?start="+start+"&count="+count+"&keywords=" + search);
 }
 
 /**
@@ -197,7 +197,7 @@ QString LinkedInAPI::search_company(QString search,QString start, QString count)
   */
 QString LinkedInAPI::search_job(QString search,QString start, QString count){
 	search = QUrl::toPercentEncoding(search);
-	return api_request("http://api.linkedin.com/v1/job-search:(jobs:(id,customer-job-code,active,expiration-date,posting-timestamp,expiration-timestamp,company:(id,name,logo-url),position:(title,location,job-functions,industries,job-type,experience-level),skills-and-experience,description-snippet,description,salary,job-poster:(id,first-name,last-name,headline),referral-bonus,site-job-url,location-description))?start="+start+"&count="+count+"&keywords=" + search);
+	return api_request("http://api.linkedin.com/v1/job-search:(jobs:(id,customer-job-code,active,expiration-date,posting-timestamp,expiration-timestamp,company:(id,name,logo-url,square-logo-url),position:(title,location,job-functions,industries,job-type,experience-level),skills-and-experience,description-snippet,description,salary,job-poster:(id,first-name,last-name,headline),referral-bonus,site-job-url,location-description))?start="+start+"&count="+count+"&keywords=" + search);
 }
 
 
@@ -209,7 +209,7 @@ QString LinkedInAPI::search_job(QString search,QString start, QString count){
   @return The url to use when posting a GET to get a list of companies the user follows
   */
 QString LinkedInAPI::get_company_following(QString start, QString count){
-	return api_request("http://api.linkedin.com/v1/people/~/following/companies:(id,name,universal-name,website-url,logo-url,type)?start="+start+"&count="+count);
+	return api_request("http://api.linkedin.com/v1/people/~/following/companies:(id,name,universal-name,website-url,logo-url,square-logo-url,type)?start="+start+"&count="+count);
 }
 
 /**
@@ -220,7 +220,7 @@ QString LinkedInAPI::get_company_following(QString start, QString count){
   @return The url to use when posting a GET to get a list of companies the user follows
   */
 QString LinkedInAPI::get_job_bookmarks(QString start, QString count){
-	return api_request("http://api.linkedin.com/v1/people/~/job-bookmarks:(job:(id,customer-job-code,active,expiration-date,posting-timestamp,expiration-timestamp,company:(id,name,logo-url),position:(title,location,job-functions,industries,job-type,experience-level),skills-and-experience,description-snippet,description,salary,job-poster:(id,first-name,last-name,headline),referral-bonus,site-job-url,location-description))?start="+start+"&count="+count);
+	return api_request("http://api.linkedin.com/v1/people/~/job-bookmarks:(job:(id,customer-job-code,active,expiration-date,posting-timestamp,expiration-timestamp,company:(id,name,logo-url,square-logo-url),position:(title,location,job-functions,industries,job-type,experience-level),skills-and-experience,description-snippet,description,salary,job-poster:(id,first-name,last-name,headline),referral-bonus,site-job-url,location-description))?start="+start+"&count="+count);
 }
 
 QString LinkedInAPI::get_connections_current(){
