@@ -9,6 +9,7 @@ User::User(QObject *parent) :
 {
 	companiesFollowed = new QHash<QString,QString>;
 	peopleConnections = new QHash<QString,QString>;
+	jobsBookmarked = new QHash<QString,QString>;
 }
 
 User::~User(){
@@ -137,8 +138,53 @@ void User::removeConnection(QString id){
 	peopleConnections->remove(id);
 }
 
+/**
+  Sets the jobs that the user has bookmarked based on an xml file
+  obtained from an OAuth reques to http://api.linkedin.com/v1/people/~/job-bookmarks.
+  @param xml The xml file that is returned from LinkedIn
+  */
+void User::setJobsBookmarked(QString xml){
+	jobsBookmarked->clear();
+
+	QDomDocument doc;
+	doc.setContent(xml);
+
+	QDomNodeList jobs = doc.elementsByTagName("job");
+
+	for(int i = 0; i < jobs.length(); i++){
+		QString key = jobs.at(i).namedItem("id").toElement().text();
+		QString value = jobs.at(i).namedItem("position").toElement().namedItem("title").toElement().text();
+		jobsBookmarked->insert(key, value);
+	}
+}
+
+/**
+  Tests to see if the user bookmarked a job
+  @param id The id of the job
+  */
+bool User::bookmarked(QString id){
+	return jobsBookmarked->contains(id);
+}
+
+/**
+  Add a job bookmark
+  @param id The id of the job
+  @param title The title of the job
+  */
+void User::bookmark(QString id, QString title){
+	jobsBookmarked->insert(id, title);
+}
+
+/**
+  Remove a job bookmark
+  @param id The id of the job
+  */
+void User::removeBookmark(QString id){
+	jobsBookmarked->remove(id);
+}
+
 void User::print(){
-	QList<QString> tmpList = peopleConnections->values();
+	QList<QString> tmpList = jobsBookmarked->values();
 	for(int i = 0; i < tmpList.length(); i++){
 		cout << tmpList.at(i).toStdString() << endl;
 	}
